#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.schema.fieldproperty import FieldProperty

from pyams_content.component.paragraph import BaseParagraph
from pyams_content.features.renderer import RenderersVocabulary
from pyams_content.shared.common.interfaces.specificities import ISharedContentSpecificitiesParagraph, \
    SHARED_CONTENT_SPECIFICITIES_PARAGRAPH_RENDERERS
from pyams_utils.factory import factory_config
from pyams_utils.vocabulary import vocabulary_config

from pyams_content import _


#
# Shared content specificities paragraph
#

SHARED_CONTENT_SPECIFICITIES_PARAGRAPH_TYPE = 'ContentSpecificities'
SHARED_CONTENT_SPECIFICITIES_PARAGRAPH_NAME = _('Content specificities')


@factory_config(provided=ISharedContentSpecificitiesParagraph)
class SharedContentSpecificitiesParagraph(BaseParagraph):
    """Shared content specificities paragraph"""

    icon_hint = _("Content specificities")
    icon_class = 'fa-paperclip'

    renderer = FieldProperty(ISharedContentSpecificitiesParagraph['renderer'])


@vocabulary_config(name=SHARED_CONTENT_SPECIFICITIES_PARAGRAPH_RENDERERS)
class SharedContentSpecificitiesParagraphRendererVocabulary(RenderersVocabulary):
    """Shared content specificities renderers vocabulary"""

    content_interface = ISharedContentSpecificitiesParagraph
